from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.fieldset import crf_status_fieldset

from ..admin_site import intecomm_subject_admin
from ..forms import VitalsForm
from ..models import Vitals
from .modeladmin_mixins import CrfModelAdmin


@admin.register(Vitals, site=intecomm_subject_admin)
class VitalsAdmin(CrfModelAdmin):
    form = VitalsForm

    additional_instructions = "To be completed by the research nurse."

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Weight, Height and Temperature",
            {
                "fields": (
                    "weight_determination",
                    "weight",
                    "height",
                    "temperature",
                )
            },
        ),
        (
            "Blood Pressure: First reading",
            {
                "description": "Refer to SOP for blood pressure measurement procedure.",
                "fields": (
                    "bp_one_taken",
                    "bp_one_not_taken_reason",
                    "sys_blood_pressure_one",
                    "dia_blood_pressure_one",
                ),
            },
        ),
        (
            "Blood Pressure: Second reading",
            {
                "description": "Refer to SOP for blood pressure measurement procedure.",
                "fields": (
                    "bp_two_taken",
                    "bp_two_not_taken_reason",
                    "sys_blood_pressure_two",
                    "dia_blood_pressure_two",
                ),
            },
        ),
        (
            "Severe hypertension",
            {
                "description": "Refer to SOP on severe hypertension.",
                "fields": ("severe_htn",),
            },
        ),
        (
            "Comments",
            {
                "fields": ("comments",),
            },
        ),
        crf_status_fieldset,
        audit_fieldset_tuple,
    )

    radio_fields = {
        "severe_htn": admin.VERTICAL,
        "weight_determination": admin.VERTICAL,
        "bp_one_taken": admin.VERTICAL,
        "bp_two_taken": admin.VERTICAL,
    }



from django import forms
from edc_form_validators import FormValidatorMixin
from edc_sites.modelform_mixins import SiteModelFormMixin

from ..models import PatientGroupMeeting


class PatientGroupMeetingForm(
    SiteModelFormMixin,
    FormValidatorMixin,
    forms.ModelForm,
):
    class Meta:
        fields = "__all__"
        model = PatientGroupMeeting



from django.apps import AppConfig as DjangoAppConfig


class AppConfig(DjangoAppConfig):
    name = "intecomm_prn"
    verbose_name = "INTECOMM: PRN Forms"
    include_in_administration_section = True
    has_exportable_data = True
    default_auto_field = "django.db.models.BigAutoField"



# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_prn", "0011_alter_endofstudy_device_created_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="endofstudy",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "End of Study",
                "verbose_name_plural": "End of Study",
            },
        ),
        migrations.AlterModelOptions(
            name="losstofollowup",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Loss to Follow Up",
                "verbose_name_plural": "Loss to Follow Up",
            },
        ),
        migrations.AlterModelOptions(
            name="offschedulecomm",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Off-schedule community-based integrated care",
                "verbose_name_plural": "Off-schedule community-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="offscheduleinte",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Off-schedule facility-based integrated care",
                "verbose_name_plural": "Off-schedule facility-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="onschedulecomm",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "On-schedule community-based integrated care",
                "verbose_name_plural": "On-schedule community-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="onscheduleinte",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "On-schedule facility-based integrated care",
                "verbose_name_plural": "On-schedule facility-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="protocolincident",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Protocol Incident",
                "verbose_name_plural": "Protocol Incident",
            },
        ),
        migrations.AlterModelOptions(
            name="subjecttransfer",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Subject Transfer",
                "verbose_name_plural": "Subject Transfers",
            },
        ),
        migrations.RemoveIndex(
            model_name="offschedulecomm",
            name="intecomm_pr_id_3f0fba_idx",
        ),
        migrations.RemoveIndex(
            model_name="offscheduleinte",
            name="intecomm_pr_id_494e36_idx",
        ),
        migrations.RemoveIndex(
            model_name="onschedulecomm",
            name="intecomm_pr_id_d4e5db_idx",
        ),
        migrations.RemoveIndex(
            model_name="onscheduleinte",
            name="intecomm_pr_id_6be831_idx",
        ),
        migrations.RemoveIndex(
            model_name="protocolincident",
            name="intecomm_pr_subject_73a582_idx",
        ),
    ]



# Generated by Django 4.2.3 on 2023-08-03 16:05

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0086_rename_hoh_employment_healtheconomicshouseholdhead_hoh_employment_status_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_citizen",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient a citizen of this country?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicspatient",
            name="pat_citizen",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient a citizen of this country?",
            ),
        ),
    ]



# Generated by Django 4.1.2 on 2022-11-22 15:30

from django.db import migrations
import django_crypto_fields.fields.encrypted_char_field


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0006_remove_historicalpatientcall_willing_to_attend_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalpatientlog",
            name="last_4_contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                editable=False,
                help_text="auto-populated (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Last 4 digits of contact number",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientlog",
            name="last_4_hf_identifier",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                editable=False,
                help_text="auto-populated (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Last 4 digits of hf_identifier",
            ),
        ),
        migrations.AddField(
            model_name="patientlog",
            name="last_4_contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                editable=False,
                help_text="auto-populated (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Last 4 digits of contact number",
            ),
        ),
        migrations.AddField(
            model_name="patientlog",
            name="last_4_hf_identifier",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                editable=False,
                help_text="auto-populated (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Last 4 digits of hf_identifier",
            ),
        ),
    ]



from django import forms
from intecomm_form_validators.subject import DrugRefillDmFormValidator

from ..models import DrugRefillDm
from .mixins import CrfModelFormMixin


class DrugRefillDmForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = DrugRefillDmFormValidator

    class Meta:
        model = DrugRefillDm
        fields = "__all__"



from django.db import models
from edc_constants.choices import YES_NO
from edc_dx_review.model_mixins import (
    ClinicalReviewDmModelMixin,
    ClinicalReviewHivModelMixin,
    ClinicalReviewHtnModelMixin,
)
from edc_model.models import BaseUuidModel
from edc_rx.model_mixins import TreatmentPayMethodsModelMixin

from ..model_mixins import ClinicalReviewModelMixin, CrfModelMixin


class ClinicalReview(
    ClinicalReviewHivModelMixin,
    ClinicalReviewHtnModelMixin,
    ClinicalReviewDmModelMixin,
    TreatmentPayMethodsModelMixin,
    ClinicalReviewModelMixin,
    CrfModelMixin,
    BaseUuidModel,
):
    complications = models.CharField(
        verbose_name="Since last seen, has the patient had any complications",
        max_length=15,
        choices=YES_NO,
        help_text="If Yes, complete the 'Complications' CRF",
    )

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Clinical Review"
        verbose_name_plural = "Clinical Reviews"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from .end_of_study_form import EndOfStudyForm
from .loss_to_followup_form import LossToFollowupForm
from .offschedule_comm_form import OffScheduleCommForm
from .offschedule_inte_form import OffScheduleInteForm
from .onschedule_comm_form import OnScheduleCommForm
from .onschedule_inte_form import OnScheduleInteForm
from .protocol_incident_form import ProtocolIncidentForm
from .subject_locator_form import SubjectLocatorForm
from .subject_transfer_form import SubjectTransferForm



# Generated by Django 4.2.5 on 2023-10-05 01:17

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0116_auto_20230920_0058"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalnextappointment",
            name="allow_create_interim",
            field=models.BooleanField(
                default=False,
                help_text="Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.",
                verbose_name="Override date check?",
            ),
        ),
        migrations.AddField(
            model_name="nextappointment",
            name="allow_create_interim",
            field=models.BooleanField(
                default=False,
                help_text="Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.",
                verbose_name="Override date check?",
            ),
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-05 20:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_ae", "0012_aefollowup_intecomm_ae_subject_a0869e_idx_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="aetmg",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_ae_subject_a182a3_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aetmg",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_ae_action__ec3996_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="aetmg",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_ae_modifie_a1aa7e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aetmg",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_ae_user_mo_753370_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="deathreport",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_ae_action__dc0ac5_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="deathreport",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_ae_modifie_b7d689_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="deathreport",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_ae_user_mo_d87c5d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="deathreporttmg",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_ae_subject_91820c_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="deathreporttmg",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_ae_action__3601b2_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="deathreporttmg",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_ae_modifie_73a21b_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="deathreporttmg",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_ae_user_mo_d94467_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hospitalization",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_ae_subject_152c93_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hospitalization",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_ae_modifie_83f4ad_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hospitalization",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_ae_user_mo_ab1ea2_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hospitalization",
            index=models.Index(
                fields=["subject_identifier", "site"], name="intecomm_ae_subject_7604a4_idx"
            ),
        ),
    ]



from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING
from zoneinfo import ZoneInfo

from edc_constants.constants import CLINIC, COMMUNITY, DM
from edc_dx import Diagnoses
from edc_he.rule_groups import Predicates as BaseHealthEconomicsPredicates
from edc_visit_schedule.constants import MONTH12
from edc_visit_schedule.utils import is_baseline
from intecomm_rando.constants import COMMUNITY_ARM, FACILITY_ARM
from intecomm_rando.utils import get_assignment_for_subject

if TYPE_CHECKING:
    from edc_metadata.model_mixins.creates import CreatesMetadataModelMixin
    from edc_visit_tracking.model_mixins import VisitModelMixin as Base

    class RelatedVisitModel(CreatesMetadataModelMixin, Base):
        pass


class HealthEconomicsPredicates(BaseHealthEconomicsPredicates):
    @staticmethod
    def is_required_by_date(visit, **kwargs) -> bool:
        return visit.report_datetime >= datetime(2023, 6, 30, 23, 59, tzinfo=ZoneInfo("UTC"))

    @staticmethod
    def careseeking_required(visit, **kwargs) -> bool:
        """Returns True if subject has DM or multimorbidity"""
        if visit.visit_code == MONTH12:
            diagnoses = Diagnoses(
                subject_identifier=visit.subject_identifier,
                report_datetime=visit.report_datetime,
                lte=True,
            )
            dxs = [name for name in diagnoses.initial_reviews]
            return DM in [name for name in diagnoses.initial_reviews] or len(dxs) > 1
        return False


class LocationUpdatePredicates:
    @staticmethod
    def location_needs_update(visit: RelatedVisitModel, **kwargs) -> bool:
        required = False
        try:
            appt_type_name = visit.appointment.appt_type.name
        except AttributeError:
            pass
        else:
            if not is_baseline(visit):
                assignment = (
                    COMMUNITY
                    if get_assignment_for_subject(visit.subject_identifier) == COMMUNITY_ARM
                    else CLINIC
                )
                if assignment != appt_type_name:
                    required = True
        return required


class NextAppointmentPredicates:
    @staticmethod
    def is_required(visit: RelatedVisitModel, **kwargs) -> bool:
        return (
            get_assignment_for_subject(visit.subject_identifier) == FACILITY_ARM
            and visit.visit_code != MONTH12
        )



# Generated by Django 4.2.9 on 2024-02-01 14:14

import django.contrib.sites.managers
from django.db import migrations

import intecomm_consent.models.subject_consent


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_consent", "0022_subjectconsenttz_historicalsubjectconsenttz"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="subjectconsent",
            managers=[
                ("objects", intecomm_consent.models.subject_consent.ConsentObjectsManager()),
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
            ],
        ),
    ]



from django.core.validators import MaxValueValidator, MinValueValidator
from django.db import models
from edc_adherence.model_mixins import (
    MedicationAdherenceModelMixin as BaseMedicationAdherenceModelMixin,
)
from edc_model_fields.fields import OtherCharField


class MedicationAdherenceModelMixin(BaseMedicationAdherenceModelMixin):
    condition_label = None

    meds_missed_in_days = models.IntegerField(
        verbose_name="In the last month, how many days did you miss taking your medication",
        validators=[MinValueValidator(1), MaxValueValidator(180)],
        null=True,
        blank=True,
    )

    meds_shortage_in_days = models.IntegerField(
        verbose_name="In the last month, how many days did you NOT HAVE medication to take",
        validators=[MinValueValidator(1), MaxValueValidator(180)],
        null=True,
        blank=True,
        help_text="That is, your supply of medication was finished",
    )

    meds_shortage_reason = models.ManyToManyField(
        "intecomm_lists.MedicationShortageReasons",
        verbose_name="Reasons for not having medications (supply/shortage)",
        blank=True,
    )

    meds_shortage_reason_other = OtherCharField(
        verbose_name="If `other` reason for not having medications, specify"
    )

    class Meta:
        abstract = True



ADULT = "adult"
ALONE = "alone"
APPT = "appt"
APPT_OTHER = "other_routine_appt"
CHILD = "child"
COMMUNITY_CLINIC = "community_clinic"
EXPENSIVE = "expensive"
GTE_3HRS = "gte_3hr"
HOME_REMEDIES = "home_remedies"
MAIN_EARNER = "main_earner"
MISSED_VISIT_ACTION = "missed_visit_action"
NURSE = "nurse"
PAID_WORK = "paid_work"
PROBLEMATIC = "problematic"
SITTING = "sitting"
STUDY_VISIT = "study_visit"
TOO_BUSY = "too_busy"
UNAVAILABLE = "unavailable"
UNIMPORTANT = "unimportant"
UNPAID_WORK = "unpaid_work"
VERTICAL = "vertical"
VIT_B_FOLIC_ACID = "vitamin_b_folic_acid"



model_data = {
    "edc_lab.consignee": [
        {
            "name": "The INTECOMM Trial",
            "contact_name": "Sokoine Kivuyo",
            "address": "NIMR Tanzania",
            "postal_code": "-",
            "city": "Dar es Salaam",
            "state": None,
            "country": "Tanzania",
            "telephone": "+255763244779",
            "mobile": "+255763244779",
            "fax": None,
            "email": "sokoinele@yahoo.co.uk",
        }
    ]
}



# Generated by Django 4.2.10 on 2024-02-22 05:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "intecomm_subject",
            "0144_rename_meds_prescribed_careseekingb_med_prescribed_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="careseekinga",
            old_name="facility_visit_alt",
            new_name="missed_activities",
        ),
        migrations.RenameField(
            model_name="careseekinga",
            old_name="facility_duration",
            new_name="visit_duration",
        ),
        migrations.RenameField(
            model_name="careseekinga",
            old_name="alt_lost_income",
            new_name="visit_lost_income",
        ),
        migrations.RenameField(
            model_name="careseekinga",
            old_name="hworker_duration",
            new_name="with_hcw_duration",
        ),
        migrations.RenameField(
            model_name="careseekingb",
            old_name="facility_visit_alt",
            new_name="missed_activities",
        ),
        migrations.RenameField(
            model_name="careseekingb",
            old_name="facility_duration",
            new_name="visit_duration",
        ),
        migrations.RenameField(
            model_name="careseekingb",
            old_name="alt_lost_income",
            new_name="visit_lost_income",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="facility_visit_alt",
            new_name="missed_activities",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="facility_duration",
            new_name="visit_duration",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="alt_lost_income",
            new_name="visit_lost_income",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="hworker_duration",
            new_name="with_hcw_duration",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="facility_visit_alt",
            new_name="missed_activities",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="facility_duration",
            new_name="visit_duration",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="alt_lost_income",
            new_name="visit_lost_income",
        ),
    ]



from typing import Any

from django.conf import settings
from django.views.generic import TemplateView
from edc_dashboard.view_mixins import EdcViewMixin
from edc_navbar import NavbarViewMixin


class SubjectsHomeView(EdcViewMixin, NavbarViewMixin, TemplateView):
    template_name = f"intecomm_edc/bootstrap{settings.EDC_BOOTSTRAP}/subjects_home.html"
    navbar_name = settings.APP_NAME
    navbar_selected_item = "subjects"

    def get_context_data(self, **kwargs) -> dict[str, Any]:
        kwargs.update(subject_listboard_url="intecomm_dashboard:subject_listboard_url")
        return super().get_context_data(**kwargs)



from django.contrib import admin
from django.template.loader import render_to_string
from django.utils.translation import gettext as _
from django_audit_fields import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple

from ...admin_site import intecomm_subject_admin
from ...forms import CareseekingBForm
from ...models import CareseekingB
from ..modeladmin_mixins import CrfModelAdmin


@admin.register(CareseekingB, site=intecomm_subject_admin)
class CareseekingBAdmin(
    CrfModelAdmin,
):
    form = CareseekingBForm

    additional_instructions = render_to_string(
        "intecomm_subject/careseeking_b_instructions.html", context={}
    )

    fieldsets = (
        (
            _("Part B: INFORMATION ON ANY CARESEEKING IN THE PAST 3 MONTHS"),
            {"fields": ("subject_visit", "report_datetime")},
        ),
        (
            _("B1: Health visits in the past 3 months"),
            {
                "fields": (
                    "needed_care",
                    "accessed_care",
                    "no_accessed_care",
                    "no_accessed_care_other",
                    "care_facility",
                    "care_facility_other",
                    "care_type",
                    "outpatient_visits",
                )
            },
        ),
        (
            _("B2: Travel and expenses at last/most recent visit"),
            {
                "fields": (
                    "travel_method",
                    "travel_duration",
                    "travel_costs",
                    "food_costs",
                    "care_costs",
                )
            },
        ),
        (
            _("B3: Medications at last/most recent visit"),
            {
                "fields": (
                    "med_prescribed",
                    "med_conditions",
                    "med_conditions_other",
                    "med_collected",
                    "med_not_collected_reason",
                    "med_not_collected_reason_other",
                    "med_cost_tot",
                )
            },
        ),
        (
            _("B4: Tests at last/most recent visit"),
            {
                "fields": (
                    "tests_requested",
                    "tests_done",
                    "tests_not_done_reason",
                    "tests_not_done_other",
                    "tests_cost",
                )
            },
        ),
        (
            _("B5: Time and expenses at last/most recent visit"),
            {
                "fields": (
                    "care_visit_duration",
                    "missed_activities",
                    "missed_activities_other",
                )
            },
        ),
        (
            _("B6: People who accompanied you to last/most recent visit"),
            {
                "fields": (
                    "accompany",
                    "accompany_num",
                    "accompany_wait",
                    "accompany_alt",
                    "accompany_alt_other",
                )
            },
        ),
        (
            _("B7: Your expenses in the past 3 months"),
            {
                "fields": (
                    "money_sources",
                    "money_sources_other",
                    "money_source_main",
                )
            },
        ),
        (
            _("B8: About your inpatient visit"),
            {
                "fields": (
                    "inpatient",
                    "inpatient_days",
                    "inpatient_reasons",
                    "inpatient_reasons_other",
                )
            },
        ),
        (
            _("B9: Inpatient visit: expenses"),
            {
                "description": _(
                    "Continue with this section if you were admitted "
                    "as an inpatient as indicated above"
                ),
                "fields": (
                    "inpatient_cost",
                    "inpatient_accompany",
                    "inpatient_food",
                    "inpatient_food_cost",
                    "inpatient_nowork_days",
                    "inpatient_household_nowork",
                    "inpatient_household_nowork_days",
                ),
            },
        ),
        (
            _("B10: Inpatient visit: sources of payment for expenses"),
            {
                "description": _(
                    "Continue with this section if you were admitted "
                    "as an inpatient as indicated above"
                ),
                "fields": (
                    "inpatient_money_sources",
                    "inpatient_money_sources_other",
                    "inpatient_money_sources_main",
                    "inpatient_money_sources_main_other",
                ),
            },
        ),
        crf_status_fieldset_tuple,
        audit_fieldset_tuple,
    )

    filter_horizontal = [
        "travel_method",
        "med_conditions",
        "money_sources",
        "inpatient_reasons",
        "inpatient_money_sources",
    ]

    radio_fields = {
        "accompany": admin.VERTICAL,
        "accompany_alt": admin.VERTICAL,
        "accompany_wait": admin.VERTICAL,
        "crf_status": admin.VERTICAL,
        "needed_care": admin.VERTICAL,
        "inpatient": admin.VERTICAL,
        "inpatient_accompany": admin.VERTICAL,
        "inpatient_food": admin.VERTICAL,
        "inpatient_household_nowork": admin.VERTICAL,
        "inpatient_money_sources_main": admin.VERTICAL,
        "med_collected": admin.VERTICAL,
        "med_not_collected_reason": admin.VERTICAL,
        "med_prescribed": admin.VERTICAL,
        "missed_activities": admin.VERTICAL,
        "money_source_main": admin.VERTICAL,
        "no_accessed_care": admin.VERTICAL,
        "accessed_care": admin.VERTICAL,
        "care_type": admin.VERTICAL,
        "care_facility": admin.VERTICAL,
        "tests_done": admin.VERTICAL,
        "tests_not_done_reason": admin.VERTICAL,
        "tests_requested": admin.VERTICAL,
    }



# Generated by Django 4.1.7 on 2023-06-27 15:06

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0032_patientgrouprando"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="consentrefusal",
            name="subject_identifier",
        ),
        migrations.RemoveField(
            model_name="consentrefusal",
            name="subject_identifier_aka",
        ),
        migrations.RemoveField(
            model_name="consentrefusal",
            name="subject_identifier_as_pk",
        ),
        migrations.RemoveField(
            model_name="historicalconsentrefusal",
            name="subject_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalconsentrefusal",
            name="subject_identifier_aka",
        ),
        migrations.RemoveField(
            model_name="historicalconsentrefusal",
            name="subject_identifier_as_pk",
        ),
        migrations.AlterField(
            model_name="consentrefusal",
            name="subject_screening",
            field=models.OneToOneField(
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_screening.subjectscreening",
            ),
        ),
    ]



from __future__ import annotations

from typing import TYPE_CHECKING, Type

from django import forms
from django.core.exceptions import ObjectDoesNotExist
from django.utils.html import format_html

from intecomm_screening.exceptions import AlreadyConsentedError

if TYPE_CHECKING:
    from intecomm_consent.models import SubjectConsent, SubjectConsentUg
    from intecomm_screening.models import SubjectScreening, SubjectScreeningUg


def raise_if_subject_consent_exists(
    screening_identifier: str | None = None,
    subject_screening: SubjectScreening | None = None,
    subject_screening_model_cls: Type[SubjectScreening | SubjectScreeningUg | None] = None,
    subject_consent_model_cls: Type[SubjectConsent | SubjectConsentUg | None] = None,
    is_modelform: bool | None = None,
) -> None:
    """Raises an exception if subject consent model instance exists."""
    screening_identifier = screening_identifier or subject_screening.screening_identifier
    try:
        subject_consent = subject_consent_model_cls.objects.get(
            screening_identifier=screening_identifier
        )
    except ObjectDoesNotExist:
        pass
    else:
        if is_modelform:
            if not subject_screening:
                subject_screening = subject_screening_model_cls.objects.get(
                    screening_identifier=screening_identifier
                )
            msg = format_html(
                "Not allowed. Subject has already consented. See subject {}.",
                subject_screening.subject_identifier,
            )
            raise forms.ValidationError(msg)

        else:
            raise AlreadyConsentedError(
                f"Subject has already consented. See {subject_consent.subject_identifier}. "
                f"Perhaps catch this in the form."
            )



from edc_visit_schedule.schedule import Schedule

from intecomm_consent.consents import cdef_tz_v1, cdef_ug_v1

from ..constants import COMMUNITY_SCHEDULE
from .visits import get_followup_visit, visit00, visit12

community_schedule = Schedule(
    name=COMMUNITY_SCHEDULE,
    verbose_name="Community-based integrated care",
    onschedule_model="intecomm_prn.onschedulecomm",
    offschedule_model="intecomm_prn.offschedulecomm",
    consent_definitions=[cdef_tz_v1, cdef_ug_v1],
    appointment_model="edc_appointment.appointment",
)

visits = [visit00]
for month in range(1, 12):
    visits.append(get_followup_visit(month, allow_unscheduled=True))
visits.append(visit12)

for visit in visits:
    community_schedule.add_visit(visit=visit)



# Generated by Django 4.1.2 on 2023-01-27 01:09

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0008_historicalvitals_vitals_remove_indicators_site_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalvitals",
            name="bp_measured",
        ),
        migrations.RemoveField(
            model_name="historicalvitals",
            name="bp_not_measured_reason",
        ),
        migrations.RemoveField(
            model_name="vitals",
            name="bp_measured",
        ),
        migrations.RemoveField(
            model_name="vitals",
            name="bp_not_measured_reason",
        ),
        migrations.AddField(
            model_name="historicalvitals",
            name="bp_one_not_taken_reason",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If first BP reading not done, please explain",
            ),
        ),
        migrations.AddField(
            model_name="historicalvitals",
            name="bp_one_taken",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the first blood pressure reading done",
            ),
        ),
        migrations.AddField(
            model_name="historicalvitals",
            name="bp_two_not_taken_reason",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If second BP reading not done, please explain",
            ),
        ),
        migrations.AddField(
            model_name="historicalvitals",
            name="bp_two_taken",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=15,
                null=True,
                verbose_name="Was the second blood pressure reading done",
            ),
        ),
        migrations.AddField(
            model_name="vitals",
            name="bp_one_not_taken_reason",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If first BP reading not done, please explain",
            ),
        ),
        migrations.AddField(
            model_name="vitals",
            name="bp_one_taken",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the first blood pressure reading done",
            ),
        ),
        migrations.AddField(
            model_name="vitals",
            name="bp_two_not_taken_reason",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If second BP reading not done, please explain",
            ),
        ),
        migrations.AddField(
            model_name="vitals",
            name="bp_two_taken",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=15,
                null=True,
                verbose_name="Was the second blood pressure reading done",
            ),
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-05 20:41

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0064_alter_patientcall_options_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="patientlogreportprinthistory",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_891a97_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientlogreportprinthistory",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_7c6828_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectscreening",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_sc_subject_7056ed_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectscreening",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_824618_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectscreening",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_54a1bf_idx"
            ),
        ),
        migrations.AddConstraint(
            model_name="patientlog",
            constraint=models.UniqueConstraint(
                fields=("legal_name", "initials"),
                name="intecomm_screening_patientlog_legal_n_uniq",
            ),
        ),
        migrations.AddConstraint(
            model_name="subjectscreening",
            constraint=models.UniqueConstraint(
                fields=("legal_name", "initials"),
                name="intecomm_screening_subjectscreening_legal_n_uniq",
            ),
        ),
    ]



# Generated by Django 5.0 on 2024-01-25 05:33

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_prn",
            "0015_protocolincident_intecomm_pr_subject_54092b_idx_and_more",
        ),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.AlterField(
            model_name="endofstudy",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicallosstofollowup",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicaloffschedulecomm",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicaloffscheduleinte",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalonschedulecomm",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalonscheduleinte",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectlocator",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjecttransfer",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="losstofollowup",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="offschedulecomm",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="offscheduleinte",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="onschedulecomm",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="onscheduleinte",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="subjecttransfer",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
    ]



# Generated by Django 4.2.3 on 2023-07-25 17:32

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_visit_schedule", "0010_alter_subjectschedulehistory_options_and_more"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
        ("edc_next_appointment", "0001_initial"),
        (
            "intecomm_subject",
            "0058_rename_external_remittance_currency_healtheconomicsincome_external_remit_currency_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalnextappointment",
            old_name="info_source",
            new_name="info_source_old",
        ),
        migrations.AddField(
            model_name="historicalnextappointment",
            name="visitschedule",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                help_text="Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.",
                max_length=15,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_visit_schedule.visitschedule",
                verbose_name="Which study visit code is closest to this appointment date",
            ),
        ),
        migrations.RenameField(
            model_name="nextappointment",
            old_name="info_source",
            new_name="info_source_old",
        ),
        migrations.AddField(
            model_name="nextappointment",
            name="visitschedule",
            field=models.ForeignKey(
                help_text="Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.",
                max_length=15,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_visit_schedule.visitschedule",
                verbose_name="Which study visit code is closest to this appointment date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="best_visit_code",
            field=models.CharField(
                help_text="Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.",
                max_length=15,
                null=True,
                verbose_name="Which study visit code is closest to this appointment date",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="best_visit_code",
            field=models.CharField(
                help_text="Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.",
                max_length=15,
                null=True,
                verbose_name="Which study visit code is closest to this appointment date",
            ),
        ),
    ]



from django import forms
from edc_action_item.forms import ActionItemFormMixin
from edc_form_validators import FormValidatorMixin
from edc_model_form.mixins import BaseModelFormMixin
from edc_offstudy.modelform_mixins import OffstudyModelFormMixin
from edc_sites.forms import SiteModelFormMixin
from intecomm_form_validators.prn import EndOfStudyFormValidator

from ..models import EndOfStudy


class EndOfStudyForm(
    OffstudyModelFormMixin,
    ActionItemFormMixin,
    SiteModelFormMixin,
    BaseModelFormMixin,
    FormValidatorMixin,
    forms.ModelForm,
):
    form_validator_cls = EndOfStudyFormValidator

    subject_identifier = forms.CharField(
        label="Subject Identifier",
        required=False,
        widget=forms.TextInput(attrs={"readonly": "readonly"}),
    )

    class Meta:
        model = EndOfStudy
        fields = "__all__"
        labels = {"offstudy_datetime": "Date patient terminated from study:"}



# Generated by Django 4.2.3 on 2023-08-03 15:26

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0081_healtheconomicshouseholdhead_hoh_education_old_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_education",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_he.education",
                verbose_name="Highest level of education completed by the household head?",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_employment_type",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_he.employmenttype",
                verbose_name="Household head’s type of employment",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicspatient",
            name="pat_education",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_he.education",
                verbose_name="Highest level of education completed?",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicspatient",
            name="pat_employment_type",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_he.employmenttype",
                verbose_name="What is your type of employment?",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_education",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_he.education",
                verbose_name="Highest level of education completed by the household head?",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_employment_type",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_he.employmenttype",
                verbose_name="Household head’s type of employment",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicspatient",
            name="pat_education",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_he.education",
                verbose_name="Highest level of education completed?",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicspatient",
            name="pat_employment_type",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_he.employmenttype",
                verbose_name="What is your type of employment?",
            ),
        ),
    ]



from django.core.validators import MaxValueValidator, MinValueValidator
from django.db import models
from edc_constants.choices import YES_NO, YES_NO_NA
from edc_constants.constants import NOT_APPLICABLE
from edc_model.models import BaseUuidModel, OtherCharField

from intecomm_lists.models import DrugPaySources, TransportChoices

from ..choices import ACTIVITY_CHOICES, CHILDCARE_CHOICES
from ..model_mixins import CrfModelMixin

# Not used


class HealthEconomics(CrfModelMixin, BaseUuidModel):
    occupation = models.CharField(
        verbose_name="What is your occupation/profession?", max_length=50
    )

    education_in_years = models.IntegerField(
        verbose_name="How many years of education did you complete?",
        validators=[MinValueValidator(0), MaxValueValidator(50)],
    )

    education_certificate = models.CharField(
        verbose_name="What is your highest education certificate?",
        max_length=50,
        null=True,
        blank=True,
    )

    primary_school = models.CharField(
        verbose_name="Did you go to primary/elementary school?",
        max_length=15,
        choices=YES_NO_NA,
    )

    primary_school_in_years = models.IntegerField(
        verbose_name="If YES, for how many years",
        validators=[MinValueValidator(0), MaxValueValidator(10)],
        null=True,
        blank=True,
    )

    secondary_school = models.CharField(
        verbose_name="Did you go to secondary school?", max_length=15, choices=YES_NO_NA
    )

    secondary_school_in_years = models.IntegerField(
        verbose_name="If YES, for how many years",
        validators=[MinValueValidator(0), MaxValueValidator(10)],
        null=True,
        blank=True,
    )

    higher_education = models.CharField(
        verbose_name="Did you go to higher education?", max_length=15, choices=YES_NO_NA
    )

    higher_education_in_years = models.IntegerField(
        verbose_name="If YES, for how many years",
        validators=[MinValueValidator(0), MaxValueValidator(10)],
        null=True,
        blank=True,
    )

    welfare = models.CharField(
        verbose_name="Do you receive any welfare or social service support",
        max_length=15,
        choices=YES_NO,
    )

    welfare_other = models.TextField(
        verbose_name="If yes, please explain", max_length=250, null=True, blank=True
    )

    income_per_month = models.IntegerField(
        verbose_name="How much do you earn (take home) per month?",
        help_text="in local currency",
        null=True,
        blank=False,
    )

    household_income_per_month = models.IntegerField(
        verbose_name="What is the total income in your household per month?",
        help_text="in local currency",
        null=True,
        blank=False,
    )

    is_highest_earner = models.CharField(
        verbose_name="Are you the person who earns the highest income in your household?",
        max_length=15,
        choices=YES_NO,
        null=True,
        blank=False,
    )

    highest_earner = models.CharField(
        verbose_name=(
            "If NO, what is the profession of the person who earns the highest income?"
        ),
        max_length=50,
        null=True,
        blank=True,
    )

    # General expenditure
    food_per_month = models.IntegerField(
        verbose_name="How much do you/your family spend on food in a month?",
        help_text="in local currency",
        null=True,
        blank=False,
    )

    accomodation_per_month = models.IntegerField(
        verbose_name=(
            "How much do you/your family spend on rent (or house loan/mortgage) "
            "and utilities in a month?"
        ),
        help_text="in local currency",
        null=True,
        blank=False,
    )

    large_expenditure_year = models.IntegerField(
        verbose_name="How much have you spent on large items in the last year",
        help_text="e.g. furniture, electrical items, cars (in local currency)",
        null=True,
        blank=False,
    )
    #################################################
    # Previous health care expenses: Medications
    received_rx_month = models.CharField(
        verbose_name=(
            "Over the last month, did you get any drugs on "
            "your visit to the health facility?"
        ),
        max_length=15,
        choices=YES_NO,
        help_text="not including today",
    )

    rx_dm_month = models.CharField(
        verbose_name=(
            "Did you receive drugs for raised blood sugar (diabetes) over the last month?"
        ),
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        help_text="not including today",
    )
    rx_dm_paid_month = models.ManyToManyField(
        DrugPaySources,
        related_name="+",
        verbose_name="If YES, how were these paid for?",
        blank=True,
    )

    rx_dm_paid_month_other = OtherCharField(
        verbose_name="If 'other pay source', please specify ... (DM)"
    )

    rx_dm_cost_month = models.IntegerField(
        verbose_name="If these drugs were not free, how much did you pay?",
        validators=[MinValueValidator(0)],
        null=True,
        blank=True,
        help_text="In local currency",
    )

    rx_htn_month = models.CharField(
        verbose_name=(
            "Did you receive drugs for raised blood pressure "
            "(hypertension) over the last month?"
        ),
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        help_text="not including today",
    )

    rx_htn_paid_month = models.ManyToManyField(
        DrugPaySources,
        related_name="+",
        verbose_name="If YES, how were these paid for?",
        blank=True,
    )

    rx_htn_paid_month_other = OtherCharField(
        verbose_name="If 'other pay source', please specify ...(HTN)"
    )

    rx_htn_cost_month = models.IntegerField(
        verbose_name="If these drugs were not free, how much did you pay?",
        validators=[MinValueValidator(0)],
        null=True,
        blank=True,
        help_text="In local currency",
    )

    rx_hiv_month = models.CharField(
        verbose_name="Did you receive anti-retroviral drugs for HIV over the last month?",
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        help_text="not including today",
    )
    rx_hiv_paid_month = models.ManyToManyField(
        DrugPaySources,
        related_name="+",
        verbose_name="If YES, how were these paid for?",
        max_length=25,
        blank=True,
    )

    rx_hiv_paid_month_other = OtherCharField(
        verbose_name="If 'other pay source', please specify ... (HIV)"
    )

    rx_hiv_cost_month = models.IntegerField(
        verbose_name="If these drugs were not free, how much did you pay?",
        validators=[MinValueValidator(0)],
        null=True,
        blank=True,
        help_text="In local currency",
    )

    rx_other_month = models.CharField(
        verbose_name="Did you receive any 'other' drugs?",
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
    )

    rx_other_paid_month = models.ManyToManyField(
        DrugPaySources,
        related_name="+",
        verbose_name="If YES, received 'other' drugs, how were these paid for?",
        blank=True,
    )

    rx_other_paid_month_other = OtherCharField(
        verbose_name="If 'other pay source', please specify ..."
    )

    rx_other_cost_month = models.IntegerField(
        verbose_name="If not free, how much did you pay for these 'other' drugs?",
        validators=[MinValueValidator(0)],
        null=True,
        blank=True,
        help_text="In local currency",
    )

    #################################################
    # Previous health care expenses: Other

    non_drug_activities_month = models.CharField(
        verbose_name=(
            "Over the last month, did you spend money on other activities (not drugs) "
            "relating to your health?"
        ),
        max_length=15,
        choices=YES_NO,
        null=True,
        blank=False,
    )

    non_drug_activities_detail_month = models.TextField(
        verbose_name="If YES, what was the activity", null=True, blank=True
    )

    non_drug_activities_cost_month = models.IntegerField(
        verbose_name=(
            "If YES, how much was spent on other activities "
            "(not drugs) relating to your health?"
        ),
        validators=[MinValueValidator(0)],
        help_text="In local currency",
        null=True,
        blank=True,
    )

    healthcare_expenditure_total_month = models.IntegerField(
        verbose_name=(
            "How much in total has been spent on your healthcare in the last month?"
        ),
        validators=[MinValueValidator(0)],
        help_text="In local currency",
        null=True,
        blank=False,
    )

    #################################################
    # Loss of Productivity and Earnings
    missed_routine_activities = models.CharField(
        verbose_name=(
            "What would you be doing if you had not come to the health facility today?"
        ),
        max_length=25,
        choices=ACTIVITY_CHOICES,
        null=True,
        blank=False,
    )

    missed_routine_activities_other = models.CharField(
        verbose_name="If OTHER, please specify", max_length=50, null=True, blank=True
    )

    off_work_days = models.DecimalField(
        verbose_name="How much time did you take off work?",
        decimal_places=1,
        max_digits=4,
        help_text="in days. (1,2,3 etc. If half-day 0.5)",
        null=True,
        blank=False,
    )

    travel_time = models.CharField(
        verbose_name="How long did it take you to reach here?",
        max_length=5,
        help_text="in hours and minutes (format HH:MM)",
        null=True,
        blank=False,
    )

    hospital_time = models.CharField(
        verbose_name="How much time did you spend at the health care facility?",
        max_length=5,
        help_text="in hours and minutes (format HH:MM)",
        null=True,
        blank=False,
    )

    lost_income = models.CharField(
        verbose_name="Did you lose earnings as a result of coming here today? ",
        max_length=15,
        choices=YES_NO,
        null=True,
        blank=False,
    )

    lost_income_amount = models.IntegerField(
        verbose_name="If Yes, how much did you lose?",
        validators=[MinValueValidator(0)],
        null=True,
        blank=True,
        help_text="In local currency",
    )

    #################################################
    # Family Loss of Productivity and Earnings
    childcare = models.CharField(
        verbose_name=(
            "Did you ask anyone else, such as your family member/"
            "friend to look after your child/children in order to come here?"
        ),
        max_length=15,
        choices=YES_NO,
        null=True,
        blank=False,
    )

    childcare_source = models.CharField(
        verbose_name=(
            "If Yes, what would they have been doing if they had not stayed to "
            "look after your child or children?"
        ),
        max_length=25,
        choices=CHILDCARE_CHOICES,
        default=NOT_APPLICABLE,
        null=True,
        blank=False,
    )

    childcare_source_other = OtherCharField()

    childcare_source_timeoff = models.DecimalField(
        verbose_name="How much time did a family member or friend take off?",
        decimal_places=1,
        max_digits=4,
        null=True,
        blank=True,
        help_text="in days. (1,2,3 etc. If half-day 0.5)",
    )

    #################################################
    # Current visit: transport and food
    transport = models.ManyToManyField(
        TransportChoices,
        verbose_name="Which form of transport did you take to get to the hospital today?",
        max_length=25,
        blank=False,
    )

    transport_other = OtherCharField(verbose_name="If 'other reason', please specify ...")

    transport_cost = models.IntegerField(
        verbose_name="How much did you spend on transport in total?",
        help_text="Coming to the health care facility going back home. (In local currency)",
        null=True,
        blank=False,
    )

    food_cost = models.IntegerField(
        verbose_name=(
            "How much did you spend on food while "
            "you were at the health care faility today?"
        ),
        validators=[MinValueValidator(0)],
        help_text="In local currency",
        null=True,
        blank=False,
    )

    #######################################################
    # Current Visit: health care expenses
    received_rx_today = models.CharField(
        verbose_name="Did you get any drugs on your visit to the health facility today?",
        max_length=15,
        choices=YES_NO,
    )

    rx_dm_today = models.CharField(
        verbose_name="Did you receive drugs for raised blood sugar (diabetes) today?",
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
    )
    rx_dm_paid_today = models.ManyToManyField(
        DrugPaySources,
        related_name="+",
        verbose_name=(
            "If YES, received raised blood sugar (diabetes) drugs, how were these paid for?"
        ),
        blank=True,
    )

    rx_dm_paid_today_other = OtherCharField(
        verbose_name="If 'other pay source', please specify ..."
    )

    rx_dm_cost_today = models.IntegerField(
        verbose_name=(
            "If not free, how much did you pay for raised blood sugar (diabetes) drugs?"
        ),
        validators=[MinValueValidator(0)],
        null=True,
        blank=True,
        help_text="In local currency",
    )

    rx_htn_today = models.CharField(
        verbose_name="Did you receive raised blood pressure (hypertension) drugs today?",
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
    )

    rx_htn_paid_today = models.ManyToManyField(
        DrugPaySources,
        related_name="+",
        verbose_name=(
            "If YES, received high blood pressure "
            "(Hypertension) drugs, how were these paid for?"
        ),
        blank=True,
    )

    rx_htn_paid_today_other = OtherCharField(
        verbose_name="If 'other pay source', please specify ..."
    )
    rx_htn_cost_today = models.IntegerField(
        verbose_name=(
            "If not free, how much did you pay for high blood pressure (Hypertension) drugs?"
        ),
        validators=[MinValueValidator(0)],
        null=True,
        blank=True,
        help_text="In local currency",
    )

    rx_hiv_today = models.CharField(
        verbose_name="Did you receive ARVs (HIV) today?",
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
    )

    rx_hiv_paid_today = models.ManyToManyField(
        DrugPaySources,
        related_name="+",
        verbose_name="If YES, received ARV (HIV) drugs, how were these paid for?",
        max_length=25,
        blank=True,
    )

    rx_hiv_paid_today_other = OtherCharField(
        verbose_name="If 'other pay source', please specify ..."
    )

    rx_hiv_cost_today = models.IntegerField(
        verbose_name="If not free, how much did you pay for ARV (HIV) drugs?",
        validators=[MinValueValidator(0)],
        null=True,
        blank=True,
        help_text="In local currency",
    )

    rx_other_today = models.CharField(
        verbose_name="Did you receive 'other' drugs today?",
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
    )

    rx_other_paid_today = models.ManyToManyField(
        DrugPaySources,
        related_name="+",
        verbose_name="If YES, received 'other' drugs, how were these paid for?",
        blank=True,
    )

    rx_other_paid_today_other = OtherCharField(
        verbose_name="If 'other pay source', please specify ..."
    )

    rx_other_cost_today = models.IntegerField(
        verbose_name="If not free, how much did you pay for these 'other' drugs?",
        validators=[MinValueValidator(0)],
        null=True,
        blank=True,
        help_text="In local currency",
    )
    ########################################################
    # Current Visit: Other expenses

    non_drug_activities_today = models.CharField(
        verbose_name=(
            "Did you spend money on other activities (not drugs) "
            "relating to your health today?"
        ),
        max_length=15,
        choices=YES_NO,
        null=True,
        blank=False,
    )

    non_drug_activities_detail_today = models.TextField(
        verbose_name="If YES, what was the activity", null=True, blank=True
    )

    non_drug_activities_cost_today = models.IntegerField(
        verbose_name="If YES, how much did you spend?",
        validators=[MinValueValidator(0)],
        help_text="In local currency",
        null=True,
        blank=True,
    )

    healthcare_expenditure_total_month_today = models.IntegerField(
        verbose_name=(
            "How much in total has been spent on your healthcare in the last month?"
        ),
        validators=[MinValueValidator(0)],
        help_text="In local currency",
        null=True,
        blank=False,
    )

    ########################################################
    # Health care financing
    finance_by_sale = models.CharField(
        verbose_name="Do you sell anything to pay for your visit today?",
        max_length=15,
        choices=YES_NO,
        null=True,
        blank=False,
    )

    finance_by_loan = models.CharField(
        verbose_name="Did you take any loans to pay for your visit?",
        max_length=15,
        choices=YES_NO,
        null=True,
        blank=False,
    )

    health_insurance = models.CharField(
        verbose_name="Do you have private healthcare insurance?",
        max_length=15,
        choices=YES_NO,
    )

    health_insurance_cost = models.IntegerField(
        verbose_name=(
            "If Yes, how much do you pay towards your contributions to "
            "healthcare insurance every month?"
        ),
        null=True,
        blank=True,
        help_text="in local currency",
    )

    patient_club = models.CharField(
        verbose_name="Do you contribute to a patient club?",
        max_length=15,
        choices=YES_NO,
    )

    patient_club_cost = models.IntegerField(
        verbose_name=(
            "If Yes, how much do you pay towards your contributions to "
            "the patient club every month?"
        ),
        null=True,
        blank=True,
        help_text="in local currency",
    )

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Health Economics"
        verbose_name_plural = "Health Economics"



# Generated by Django 4.2.3 on 2023-07-20 03:10

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_prn", "0009_subjectlocator_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="historicalsubjectlocator",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Subject Locator",
                "verbose_name_plural": "historical Subject Locators",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectlocator",
            options={
                "verbose_name": "Subject Locator",
                "verbose_name_plural": "Subject Locators",
            },
        ),
    ]



from django import forms
from intecomm_form_validators.subject import HtnReviewFormValidator

from ..models import HtnReview
from .mixins import CrfModelFormMixin


class HtnReviewForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = HtnReviewFormValidator

    class Meta:
        model = HtnReview
        fields = "__all__"



# Generated by Django 5.0.4 on 2024-04-10 21:18

import edc_model_fields.fields.custom_django_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        ("intecomm_subject", "0156_careseekinga_accompany_alt_other_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekingb",
            name="med_conditions",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                blank=True,
                limit_choices_to={"name__in": ["HIV", "dm", "htn", "OTHER"]},
                metadata="FOUTMEDCOND1",
                related_name="%(app_label)s_med_conditions_related",
                related_query_name="%(app_label)s_med_conditions_sources",
                to="intecomm_lists.conditions",
                verbose_name="What were the medicines were for?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="seek_advice",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="from a public facility, local pharmacy, traditional doctor, etc",
                max_length=15,
                metadata="FSEEK1",
                verbose_name="Did you seek advice or treatment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="seek_advice",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="from a public facility, local pharmacy, traditional doctor, etc",
                max_length=15,
                metadata="FSEEK1",
                verbose_name="Did you seek advice or treatment?",
            ),
        ),
    ]



# Generated by Django 5.0.3 on 2024-03-13 22:03

import django.core.validators
import edc_model_fields.fields.custom_django_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0151_alter_drugrefilldm_modifications_reason_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="careseekinga",
            old_name="visit_cost",
            new_name="care_visit_cost",
        ),
        migrations.RenameField(
            model_name="careseekinga",
            old_name="visit_lost_income",
            new_name="care_visit_lost_income",
        ),
        migrations.RenameField(
            model_name="careseekinga",
            old_name="visit_reason",
            new_name="care_visit_reason",
        ),
        migrations.RenameField(
            model_name="careseekingb",
            old_name="visit_duration",
            new_name="care_visit_duration",
        ),
        migrations.RenameField(
            model_name="careseekingb",
            old_name="visit_lost_income",
            new_name="care_visit_lost_income",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="visit_cost",
            new_name="care_visit_cost",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="visit_lost_income",
            new_name="care_visit_lost_income",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="visit_duration",
            new_name="care_visit_duration",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="visit_lost_income",
            new_name="care_visit_lost_income",
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="travel_time",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FTRATIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long did it take you to reach here?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="visit_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FFACTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How much time did you spend during your visit today -- from arrival to this place until the end of your visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="wait_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FWAITIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How much time did you spend waiting?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="with_hcw_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FWORKTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How much time did you spend with the healthcare worker?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="travel_time",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FTRATIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long did it take you to reach here?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="visit_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FFACTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How much time did you spend during your visit today -- from arrival to this place until the end of your visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="wait_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FWAITIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How much time did you spend waiting?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="with_hcw_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FWORKTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How much time did you spend with the healthcare worker?",
            ),
        ),
    ]



from __future__ import annotations

import datetime as dt
from zoneinfo import ZoneInfo

import time_machine
from dateutil.relativedelta import relativedelta
from django.conf import settings
from django.contrib.sites.models import Site
from django.core.management import call_command
from django.test import TestCase
from edc_constants.constants import COMPLETE, DM, HTN, MALE, NO, NOT_APPLICABLE, YES
from edc_he.constants import WIFE_HUSBAND
from edc_he.models import (
    Education,
    EmploymentType,
    Ethnicities,
    InsuranceTypes,
    Religions,
)
from edc_metadata import KEYED, NOT_REQUIRED, REQUIRED
from edc_metadata.models import CrfMetadata
from edc_metadata.utils import refresh_metadata_for_timepoint
from edc_utils import get_utcnow
from edc_visit_schedule.constants import DAY1
from faker import Faker

from intecomm_screening.tests.intecomm_test_case_mixin import IntecommTestCaseMixin
from intecomm_subject.forms import (
    HealthEconomicsHouseholdHeadForm,
    HealthEconomicsPatientForm,
)
from intecomm_subject.models import ClinicalReviewBaseline, HealthEconomicsHouseholdHead

fake = Faker()


def get_obj(model_cls, name: str = None):
    if name:
        obj = model_cls.objects.get(name=name)
    else:
        obj = model_cls.objects.all()[0]
    return obj


def get_m2m_qs(model_cls, name: str = None):
    if name:
        qs = model_cls.objects.filter(name=name)
    else:
        name = model_cls.objects.all()[0].name
        qs = model_cls.objects.filter(name=name).exclude(name=NOT_APPLICABLE)
    return qs


utc_tz = ZoneInfo("UTC")


@time_machine.travel(dt.datetime(2023, 8, 11, 8, 00, tzinfo=utc_tz))
class TestHe(IntecommTestCaseMixin, TestCase):
    patient_group = None

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.patient_group = cls.get_randomized_patient_group(
            report_datetime=get_utcnow() - relativedelta(days=10)
        )

    def setUp(self):
        self.assertTrue(self.patient_group.randomized)

    @staticmethod
    def get_hoh_options(not_applicable: str | None = None) -> dict:
        if not_applicable:
            opts = dict(
                relationship_to_hoh=NOT_APPLICABLE,
                hoh_employment_status=NOT_APPLICABLE,
                hoh_marital_status=NOT_APPLICABLE,
                hoh_religion=get_obj(Religions, NOT_APPLICABLE),
                hoh_ethnicity=get_obj(Ethnicities, NOT_APPLICABLE),
                hoh_education=get_obj(Education, NOT_APPLICABLE),
                hoh_employment_type=get_obj(EmploymentType, NOT_APPLICABLE),
                hoh_insurance=get_m2m_qs(InsuranceTypes, NOT_APPLICABLE),
                crf_status=COMPLETE,
                site=Site.objects.get(id=settings.SITE_ID),
            )
        else:
            opts = dict(
                relationship_to_hoh=WIFE_HUSBAND,
                hoh_employment_status="1",
                hoh_marital_status="1",
                hoh_religion=get_obj(Religions),
                hoh_ethnicity=get_obj(Ethnicities),
                hoh_education=get_obj(Education),
                hoh_employment_type=get_obj(EmploymentType),
                hoh_insurance=get_m2m_qs(InsuranceTypes),
                crf_status=COMPLETE,
                site=Site.objects.get(id=settings.SITE_ID),
            )
        return opts

    def test_with_models(self):
        ClinicalReviewBaseline.objects.all().delete()
        HealthEconomicsHouseholdHead.objects.all().delete()
        call_command("update_metadata")
        patient_log = self.patient_group.patients.filter(conditions__name__in=[DM]).first()
        subject_visit = self.get_subject_visit(
            subject_identifier=patient_log.subject_identifier
        )
        traveller = time_machine.travel(subject_visit.report_datetime)
        traveller.start()
        self.get_or_create_clinical_review_baseline(patient_log, subject_visit)
        opts = dict(
            hoh=NO,
            subject_visit=subject_visit,
            report_datetime=subject_visit.report_datetime,
            hh_count=4,
            hh_minors_count=1,
            hoh_gender=MALE,
            hoh_age=52,
            **self.get_hoh_options(),
        )
        del opts["hoh_insurance"]
        hoh_obj = HealthEconomicsHouseholdHead.objects.create(**opts)
        hoh_obj.hoh_insurance.add(get_obj(InsuranceTypes))
        qs = CrfMetadata.objects.filter(
            model="intecomm_subject.healtheconomicspatient",
            entry_status=NOT_REQUIRED,
            visit_code=DAY1,
            subject_identifier=patient_log.subject_identifier,
        )
        self.assertTrue(qs.exists())

        hoh_obj.hoh = YES
        hoh_obj.hoh_gender = NOT_APPLICABLE
        hoh_obj.hoh_age = None
        hoh_obj.relationship_to_hoh = NOT_APPLICABLE
        hoh_obj.hoh_employment_status = NOT_APPLICABLE
        hoh_obj.hoh_marital_status = NOT_APPLICABLE
        hoh_obj.hoh_religion = get_obj(Religions, NOT_APPLICABLE)
        hoh_obj.hoh_ethnicity = get_obj(Ethnicities, NOT_APPLICABLE)
        hoh_obj.hoh_education = get_obj(Education, NOT_APPLICABLE)
        hoh_obj.hoh_employment_type = get_obj(EmploymentType, NOT_APPLICABLE)
        hoh_obj.save()

        qs = CrfMetadata.objects.filter(
            model="intecomm_subject.healtheconomicspatient",
            entry_status=REQUIRED,
            visit_code=DAY1,
            subject_identifier=patient_log.subject_identifier,
        )
        self.assertTrue(qs.exists())

    def test_with_forms_is_hoh(self):
        """Assert if patient is Head of Household, complete Head of Household data on
        Patient form, not on the Head of Household form.
        """
        ClinicalReviewBaseline.objects.all().delete()
        HealthEconomicsHouseholdHead.objects.all().delete()
        call_command("update_metadata")
        patient_log = self.patient_group.patients.filter(conditions__name__in=[HTN]).first()
        subject_visit = self.get_subject_visit(
            subject_identifier=patient_log.subject_identifier
        )

        traveller = time_machine.travel(subject_visit.report_datetime)
        traveller.start()
        self.get_or_create_clinical_review_baseline(patient_log, subject_visit)
        cleaned_data = dict(
            subject_visit=subject_visit,
            report_datetime=subject_visit.report_datetime,
            hh_count=4,
            hh_minors_count=1,
            hoh=YES,  # patient is HoH
            hoh_gender=NOT_APPLICABLE,
            hoh_age=None,
            **self.get_hoh_options(NOT_APPLICABLE),
        )
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertEqual({}, form._errors)

        cleaned_data.update(relationship_to_hoh=WIFE_HUSBAND)
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("relationship_to_hoh", form._errors)
        cleaned_data.update(relationship_to_hoh=NOT_APPLICABLE)

        cleaned_data.update(hoh_religion=get_obj(Religions))
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_religion", form._errors)
        cleaned_data.update(hoh_religion=get_obj(Religions, NOT_APPLICABLE))

        cleaned_data.update(hoh_ethnicity=get_obj(Ethnicities))
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_ethnicity", form._errors)
        cleaned_data.update(hoh_ethnicity=get_obj(Ethnicities, NOT_APPLICABLE))

        cleaned_data.update(hoh_education=get_obj(Education))
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_education", form._errors)
        cleaned_data.update(hoh_education=get_obj(Education, NOT_APPLICABLE))

        cleaned_data.update(hoh_employment_status="1")
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_employment_status", form._errors)
        cleaned_data.update(hoh_employment_status=NOT_APPLICABLE)

        cleaned_data.update(hoh_employment_type=get_obj(EmploymentType))
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_employment_type", form._errors)
        cleaned_data.update(hoh_employment_type=get_obj(EmploymentType, NOT_APPLICABLE))

        cleaned_data.update(hoh_marital_status="1")
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_marital_status", form._errors)
        cleaned_data.update(hoh_marital_status=NOT_APPLICABLE)

        cleaned_data.update(hoh_insurance=get_m2m_qs(InsuranceTypes))
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_insurance", form._errors)
        cleaned_data.update(hoh_insurance=get_m2m_qs(InsuranceTypes, NOT_APPLICABLE))

        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertEqual({}, form._errors)

    def test_with_forms_is_not_hoh(self):
        ClinicalReviewBaseline.objects.all().delete()
        HealthEconomicsHouseholdHead.objects.all().delete()
        call_command("update_metadata")
        patient_log = self.patient_group.patients.filter(conditions__name__in=[HTN]).first()
        subject_visit = self.get_subject_visit(
            subject_identifier=patient_log.subject_identifier
        )
        traveller = time_machine.travel(subject_visit.report_datetime)
        traveller.start()

        cleaned_data = dict(
            subject_visit=subject_visit,
            report_datetime=subject_visit.report_datetime,
            hh_count=4,
            hh_minors_count=1,
            hoh=NO,  # patient is not HoH
            hoh_gender=MALE,
            hoh_age=52,
            **self.get_hoh_options(),
        )

        self.get_or_create_clinical_review_baseline(patient_log, subject_visit)
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertEqual({}, form._errors)

        cleaned_data.update(relationship_to_hoh=NOT_APPLICABLE)
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("relationship_to_hoh", form._errors)
        cleaned_data.update(relationship_to_hoh=WIFE_HUSBAND)

        cleaned_data.update(hoh_religion=get_obj(Religions, NOT_APPLICABLE))
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_religion", form._errors)
        cleaned_data.update(hoh_religion=get_obj(Religions))

        cleaned_data.update(hoh_ethnicity=get_obj(Ethnicities, NOT_APPLICABLE))
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_ethnicity", form._errors)
        cleaned_data.update(hoh_ethnicity=get_obj(Ethnicities))

        cleaned_data.update(hoh_education=get_obj(Education, NOT_APPLICABLE))
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_education", form._errors)
        cleaned_data.update(hoh_education=get_obj(Education))

        cleaned_data.update(hoh_employment_status=NOT_APPLICABLE)
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_employment_status", form._errors)
        cleaned_data.update(hoh_employment_status="1")

        cleaned_data.update(hoh_employment_type=get_obj(EmploymentType, NOT_APPLICABLE))
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_employment_type", form._errors)
        cleaned_data.update(hoh_employment_type=get_obj(EmploymentType))

        cleaned_data.update(hoh_marital_status=NOT_APPLICABLE)
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_marital_status", form._errors)
        cleaned_data.update(hoh_marital_status="1")

        cleaned_data.update(hoh_insurance=get_m2m_qs(InsuranceTypes, NOT_APPLICABLE))
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn("hoh_insurance", form._errors)
        cleaned_data.update(hoh_insurance=get_m2m_qs(InsuranceTypes))

        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertEqual({}, form._errors)

    def test_entered_across_visits(self):
        ClinicalReviewBaseline.objects.all().delete()
        HealthEconomicsHouseholdHead.objects.all().delete()
        call_command("update_metadata")
        patient_log = self.patient_group.patients.filter(conditions__name__in=[HTN]).first()
        subject_visit = self.get_subject_visit(
            subject_identifier=patient_log.subject_identifier
        )
        traveller = time_machine.travel(subject_visit.report_datetime)
        traveller.start()
        self.get_or_create_clinical_review_baseline(patient_log, subject_visit)
        cleaned_data = dict(
            subject_visit=subject_visit,
            report_datetime=subject_visit.report_datetime,
            hh_count=4,
            hh_minors_count=1,
            hoh=YES,  # patient is HoH
            hoh_gender=NOT_APPLICABLE,
            hoh_age=None,
            **self.get_hoh_options(NOT_APPLICABLE),
        )
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertEqual({}, form._errors)
        form.save(commit=True)

        qs = CrfMetadata.objects.filter(
            model="intecomm_subject.healtheconomicshouseholdhead",
            entry_status=KEYED,
            visit_code=subject_visit.visit_code,
            subject_identifier=patient_log.subject_identifier,
        )
        self.assertTrue(qs.exists())

        refresh_metadata_for_timepoint(subject_visit)

        qs = CrfMetadata.objects.filter(
            model="intecomm_subject.healtheconomicspatient",
            entry_status=REQUIRED,
            visit_code=subject_visit.visit_code,
            subject_identifier=patient_log.subject_identifier,
        )
        self.assertTrue(qs.exists())

        subject_visit = self.get_next_subject_visit(subject_visit)
        traveller = time_machine.travel(subject_visit.report_datetime)
        traveller.start()

        qs = CrfMetadata.objects.filter(
            model="intecomm_subject.healtheconomicshouseholdhead",
            entry_status=NOT_REQUIRED,
            visit_code=subject_visit.visit_code,
            subject_identifier=patient_log.subject_identifier,
        )
        self.assertTrue(qs.exists())

        qs = CrfMetadata.objects.filter(
            model="intecomm_subject.healtheconomicspatient",
            entry_status=REQUIRED,
            visit_code=subject_visit.visit_code,
            subject_identifier=patient_log.subject_identifier,
        )
        self.assertTrue(qs.exists())

        cleaned_data.update(
            subject_visit=subject_visit,
            report_datetime=subject_visit.report_datetime,
        )
        form = HealthEconomicsHouseholdHeadForm(data=cleaned_data)
        form.is_valid()
        self.assertIn(
            "This form has already been submitted",
            str(form._errors.get("__all__")),
        )

        cleaned_data = dict(
            subject_visit=subject_visit,
            report_datetime=subject_visit.report_datetime,
            pat_religion=get_obj(Religions),
            pat_ethnicity=get_obj(Ethnicities),
            pat_education=get_obj(Education),
            pat_employment_status="1",
            pat_employment_type=get_obj(EmploymentType),
            pat_marital_status="1",
            pat_insurance=get_m2m_qs(InsuranceTypes),
            crf_status=COMPLETE,
            site=Site.objects.get(id=settings.SITE_ID),
        )
        form = HealthEconomicsPatientForm(data=cleaned_data)
        form.is_valid()

        self.assertIn("Complete Clinical Review CRF first", form._errors.get("__all__")[0])

        self.get_or_create_clinical_review(patient_log, subject_visit)

        form = HealthEconomicsPatientForm(data=cleaned_data)
        form.is_valid()
        self.assertEqual({}, form._errors)
        form.save(commit=True)

        qs = CrfMetadata.objects.filter(
            model="intecomm_subject.healtheconomicspatient",
            entry_status=KEYED,
            visit_code=subject_visit.visit_code,
            subject_identifier=patient_log.subject_identifier,
        )
        self.assertTrue(qs.exists())

        qs = CrfMetadata.objects.filter(
            model="intecomm_subject.healtheconomicspatient",
            entry_status=NOT_REQUIRED,
            visit_code=subject_visit.previous_visit.visit_code,
            subject_identifier=patient_log.subject_identifier,
        )
        self.assertTrue(qs.exists())



from importlib.metadata import version

from multisite import SiteID

from .defaults import *  # noqa

print(f"Settings file {__file__}")
print(f"Version: {version('intecomm_edc')}")
DJANGO_DEBUG_TOOLBAR_ENABLED = False

SITE_ID = SiteID(default=1)
EDC_SITES_UAT_DOMAIN = True
EDC_CONSENT_BYPASS_CONSENT_DATETIME_VALIDATION = True
ALLOWED_HOSTS = [
    "localhost",
    "kasangati.uat.ug.intecomm.clinicedc.org",
    "kisugu.uat.ug.intecomm.clinicedc.org",
    "kiswa.uat.ug.intecomm.clinicedc.org",
    "kyazanga.uat.ug.intecomm.clinicedc.org",
    "mpigi.uat.ug.intecomm.clinicedc.org",
    "namayumba.uat.ug.intecomm.clinicedc.org",
    "namulonge.uat.ug.intecomm.clinicedc.org",
    "ndejje.uat.ug.intecomm.clinicedc.org",
    "sekiwunga.uat.ug.intecomm.clinicedc.org",
    "wakiso.uat.ug.intecomm.clinicedc.org",
    "amana.uat.tz.intecomm.clinicedc.org",
    "bagamoyo.uat.tz.intecomm.clinicedc.org",
    "rugambwa.uat.tz.intecomm.clinicedc.org",
    "hindu-mandal.uat.tz.intecomm.clinicedc.org",
    "kisarawe.uat.tz.intecomm.clinicedc.org",
    "mbagala.uat.tz.intecomm.clinicedc.org",
    "mnazi.uat.tz.intecomm.clinicedc.org",
    "mwananyamala.uat.tz.intecomm.clinicedc.org",
    "sinza.uat.tz.intecomm.clinicedc.org",
    "temeke.uat.tz.intecomm.clinicedc.org",
]

# edc_model_admin
EDC_MODEL_ADMIN_CSS_THEME = "edc_purple"
LIVE_SYSTEM = False



# Generated by Django 5.0 on 2024-01-10 22:18

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_consent", "0018_subjectconsent_intecomm_co_modifie_45691e_idx_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalsubjectconsent",
            name="model_name",
            field=models.CharField(
                editable=False,
                help_text="label_lower of this model class. Will be different if instance has been added/edited via a proxy model",
                max_length=50,
                null=True,
                verbose_name="model",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectconsentug",
            name="model_name",
            field=models.CharField(
                editable=False,
                help_text="label_lower of this model class. Will be different if instance has been added/edited via a proxy model",
                max_length=50,
                null=True,
                verbose_name="model",
            ),
        ),
        migrations.AddField(
            model_name="subjectconsent",
            name="model_name",
            field=models.CharField(
                editable=False,
                help_text="label_lower of this model class. Will be different if instance has been added/edited via a proxy model",
                max_length=50,
                null=True,
                verbose_name="model",
            ),
        ),
    ]



from django.db import models
from django.utils.translation import gettext_lazy as _
from edc_constants.choices import YES_NO
from edc_constants.constants import YES
from edc_model.models import BaseUuidModel

from ...model_mixins import CrfModelMixin


class HealthEconomicsAssets(
    CrfModelMixin,
    BaseUuidModel,
):

    assets = models.CharField(max_length=15, choices=YES_NO, default=YES)
    no_assets_explain = models.TextField(null=True, blank=False)

    income = models.CharField(max_length=15, choices=YES_NO, default=YES)
    no_income_explain = models.TextField(null=True, blank=False)

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = _("Health Economics: Checklist")
        verbose_name_plural = _("Health Economics: Checklists")
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



# Generated by Django 4.2.3 on 2023-07-11 02:35

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0053_remove_historicalhivreview_arv_initiated_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalhtnreview",
            name="dia_blood_pressure",
        ),
        migrations.RemoveField(
            model_name="historicalhtnreview",
            name="sys_blood_pressure",
        ),
        migrations.RemoveField(
            model_name="htnreview",
            name="dia_blood_pressure",
        ),
        migrations.RemoveField(
            model_name="htnreview",
            name="sys_blood_pressure",
        ),
    ]



from __future__ import annotations

from edc_model_admin.admin_site import EdcAdminSite
from edc_sites.site import sites
from intecomm_rando.constants import UGANDA

from intecomm_screening.intecomm_admin_site_mixin import IntecommAdminSiteMixin

from .apps import AppConfig


class IntecommConsentSite(IntecommAdminSiteMixin, EdcAdminSite):
    @staticmethod
    def get_hidden_models(request) -> dict:
        if sites.get_current_country(request) == UGANDA:
            hidden_models = {"intecomm_consent": ["SubjectConsent"]}
        else:
            hidden_models = {"intecomm_consent": ["SubjectConsentUg"]}
        return hidden_models


intecomm_consent_admin = IntecommConsentSite(
    name="intecomm_consent_admin", app_label=AppConfig.name
)



# Generated by Django 4.2.9 on 2024-02-01 15:51

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0140_historicalhivreview_drawn_date_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="viralloadresult",
            name="requisition",
        ),
        migrations.RemoveField(
            model_name="viralloadresult",
            name="site",
        ),
        migrations.RemoveField(
            model_name="viralloadresult",
            name="subject_visit",
        ),
        migrations.DeleteModel(
            name="HistoricalViralLoadResult",
        ),
        migrations.DeleteModel(
            name="ViralLoadResult",
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-05 20:48

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0135_hivinitialreview_intecomm_su_subject_a055c4_idx_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="subjectvisit",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_dab86a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectvisit",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_f69a2b_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectvisitmissed",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_4156bd_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectvisitmissed",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_4811c1_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectvisitmissed",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_fe71a2_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="urinedipsticktest",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_c286ff_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="urinedipsticktest",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_4ae4df_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="urinedipsticktest",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_e6c69a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="urinepregnancy",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_5f4648_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="urinepregnancy",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_f7bfa9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="urinepregnancy",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_a8c595_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="viralloadresult",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_c4b38b_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="viralloadresult",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_ec7d6d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="viralloadresult",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_9a68e1_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="vitals",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_4ab411_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="vitals",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_b2e5cb_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="vitals",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_4457e4_idx"
            ),
        ),
        migrations.AddConstraint(
            model_name="subjectrequisition",
            constraint=models.UniqueConstraint(
                fields=("panel", "subject_visit"),
                name="intecomm_subject_subjectrequisition_panel_uniq",
            ),
        ),
    ]



# Generated by Django 5.0.4 on 2024-04-10 22:05

import django.core.validators
import edc_model_fields.fields.custom_django_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        (
            "intecomm_subject",
            "0161_rename_inpatient_accompany_nowork_careseekingb_inpatient_household_nowork_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_cost",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FINCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much was spent in total on your hospital stay?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_food_cost",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FINFOODCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much was spent on this food and drink?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_household_nowork_days",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FINODAYSMISS1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(90),
                ],
                verbose_name="How many days did they not go to work?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_money_sources",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                blank=True,
                help_text="Select up to three sources. If 'other', please specify.",
                metadata="FINSOURCE",
                related_name="%(app_label)s_inpatient_money_sources_related",
                related_query_name="%(app_label)s_inpatient_money_sources",
                to="intecomm_lists.moneysources",
                verbose_name="What were the source(s) of payment for all these expenses for your hospital stay?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_money_sources_main",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                blank=True,
                metadata="FINSOURCEMAIN1",
                related_name="%(app_label)s_inpatient_money_sources_main_related",
                related_query_name="%(app_label)s_inpatient_money_main_sources",
                to="intecomm_lists.moneysources",
                verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_nowork_days",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FINWRKMISS1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(90),
                ],
                verbose_name="When you were ill, how many days were you not able to go to work?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_reasons",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                blank=True,
                metadata="FINDAYSCOND1",
                related_name="%(app_label)s_inpatient_reasons_related",
                related_query_name="%(app_label)s_inpatient_reasons_sources",
                to="intecomm_lists.conditions",
                verbose_name="What was this INPATIENT care for?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient_cost",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FINCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much was spent in total on your hospital stay?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient_food_cost",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FINFOODCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much was spent on this food and drink?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient_household_nowork_days",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FINODAYSMISS1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(90),
                ],
                verbose_name="How many days did they not go to work?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient_nowork_days",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FINWRKMISS1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(90),
                ],
                verbose_name="When you were ill, how many days were you not able to go to work?",
            ),
        ),
    ]



from django.utils.translation import gettext_lazy as _
from edc_constants.constants import (
    BOTH,
    DIVORCED,
    DM,
    DONT_KNOW,
    ESTIMATED,
    HIV,
    HTN,
    INPATIENT,
    LAST_WEEK,
    MARRIED,
    MEASURED,
    NEVER,
    NO,
    NOT_APPLICABLE,
    ONGOING,
    OTHER,
    OUTPATIENT,
    PATIENT,
    RESOLVED,
    SINGLE,
    TODAY,
    WIDOWED,
    YES,
    YESTERDAY,
)
from edc_dx_review.constants import DIET_LIFESTYLE, DRUGS, THIS_CLINIC
from edc_facility.constants import HEALTH_FACILITY
from edc_model_fields.utils import Choices
from edc_reportable import (
    MILLIGRAMS_PER_DECILITER,
    MILLIMOLES_PER_LITER,
    MILLIMOLES_PER_LITER_DISPLAY,
)
from edc_visit_tracking.constants import MISSED_VISIT, SCHEDULED, UNSCHEDULED

from .constants import (
    ADULT,
    ALONE,
    CHILD,
    COMMUNITY_CLINIC,
    EXPENSIVE,
    GTE_3HRS,
    HOME_REMEDIES,
    MAIN_EARNER,
    NURSE,
    PAID_WORK,
    PROBLEMATIC,
    SITTING,
    STUDY_VISIT,
    TOO_BUSY,
    UNAVAILABLE,
    UNIMPORTANT,
    UNPAID_WORK,
)

ALCOHOL_CONSUMPTION = (
    ("occasionally", _("Occasionally")),
    ("1_2_per_week", _("%(freq)s times a week") % {"freq": "1-2"}),
    ("3_4_per_week", _("%(freq)s times a week") % {"freq": "3-4"}),
    ("daily", _("Daily")),
    (NOT_APPLICABLE, _("Not applicable")),
)

CARE_ACCESS = (
    (THIS_CLINIC, _("Patient comes to this facility for their care")),
    (OTHER, _("Patient goes to a different clinic")),
    (NOT_APPLICABLE, _("Not applicable")),
)

CARE_DELIVERY = (
    (HEALTH_FACILITY, _("Health facility")),
    (COMMUNITY_CLINIC, _("Community clinic")),
    (OTHER, _("Other facility, please specify below ...")),
    (NOT_APPLICABLE, _("Not applicable")),
)

DISCLOSURE = (
    ("voluntary", _("Voluntary disclosure")),
    ("involuntary", _("Involuntary disclosure")),
    ("by_others", _("Others told them without permission")),
    (NOT_APPLICABLE, _("Not applicable")),
)

EDUCATION = (
    ("no_formal_education", _("No Formal Education")),
    ("primary", _("Up to primary")),
    ("secondary", _("Up to secondary / high school")),
    ("post_secondary", _("College or similar higher institution")),
    ("tertiary", _("university educated")),
)

EMPLOYMENT_STATUS = (
    ("professional", _("Professional / office work / business")),
    ("manual_work", _("Skilled / Unskilled manual work")),
    ("housewife", _("Housewife")),
    ("unemployed", _("Not working / seeking work")),
    ("unemployed_not_seeking", _("Not working / NOT seeking work")),
    ("retired", _("Retired")),
    (OTHER, _("Other, please specify")),
)

HOUSEHOLD_YES_NO_CHOICES = (
    (NO, _("No")),
    ("yes_spouse", _("Yes, my spouse")),
    ("yes_parents", _("Yes, one of my parents living with me")),
    ("yes_relative", _("Yes, another relative living with me")),
    (DONT_KNOW, _("Don't know")),
)

HTN_MANAGEMENT = (
    (DRUGS, _("Drugs / Medicine")),
    (DIET_LIFESTYLE, _("Diet and lifestyle alone")),
)

IMPACT_SEVERITY = (
    ("minor", _("Minor")),
    ("moderate", _("Moderate")),
    ("major", _("Major")),
    (NOT_APPLICABLE, _("Not applicable")),
)

IMPACT_STATUS = (
    (RESOLVED, _("Resolved")),
    (ONGOING, _("Ongoing")),
    (NOT_APPLICABLE, _("Not applicable")),
)

MISSED_PILLS = (
    (TODAY, _("today")),
    (YESTERDAY, _("yesterday")),
    ("earlier_this_week", _("earlier this week")),
    (LAST_WEEK, _("last week")),
    ("lt_month_ago", _("less than a month ago")),
    # ("gt_month_ago", _("more than a month ago")),
    (NEVER, _("have never missed taking my medications")),
)

MARITAL_STATUS = (
    (MARRIED, _("Married or living with someone")),
    (SINGLE, _("Single")),
    (DIVORCED, _("Divorced")),
    (WIDOWED, _("Widow / Spinster")),
)


# *********************************
ACTIVITY_CHOICES = (
    ("working", _("Working")),
    ("studying", _("Studying")),
    ("caring_for_children", _("Caring for children")),
    ("house_maintenance", _("House maintenance")),
    ("nothing", _("Nothing")),
    (OTHER, _("Other, please specify")),
)

CARD_TYPE_CHOICES = (
    ("paper_based", _("Paper-based")),
    ("electronic", _("Electronic")),
    ("both", _("Both")),
    (NOT_APPLICABLE, _("Not Applicable")),
)

CHILDCARE_CHOICES = (
    (NOT_APPLICABLE, _("Not applicable")),
    ("working", _("Working")),
    ("studying", _("Studying")),
    ("caring_for_children", _("Caring for children")),
    ("house_maintenance", _("House maintenance")),
    ("nothing", _("Nothing")),
    (OTHER, _("Other, specify")),
)

GLUCOSE_UNITS = (
    (MILLIGRAMS_PER_DECILITER, MILLIGRAMS_PER_DECILITER),
    (MILLIMOLES_PER_LITER, MILLIMOLES_PER_LITER_DISPLAY),
    (NOT_APPLICABLE, _("Not applicable")),
)

HCF_PRESCRIPTION_COLLECTION_CHOICES = (
    (YES, _("Yes")),
    (NO, _("No, I buy my own drugs")),
    (NOT_APPLICABLE, _("Not applicable")),
)

INFO_SOURCE = (
    ("patient", _("Patient")),
    ("patient_and_outpatient", _("Patient, hospital notes and/or outpatient card")),
    ("patient_representive", _("Patient Representative (e.family member, friend)")),
    ("hospital_notes", _("Hospital notes")),
    ("outpatient_cards", _("Outpatient cards")),
    ("collateral_history", _("Collateral History from relative/guardian")),
    (NOT_APPLICABLE, _("Not applicable")),
    (OTHER, _("Other")),
)

MEDS_NOT_TAKEN_REASON = (
    (NOT_APPLICABLE, _("Not applicable")),
    (OTHER, _("Other, specify below ...")),
)

MISSED_VISIT_CALLER_CHOICES = (
    (NURSE, _("Nurse")),
    (OTHER, _("Other")),
    (NOT_APPLICABLE, _("Not applicable")),
)


PHYSICAL_ACTIVITY = (
    ("retired", _("Retired")),
    (SITTING, _("Mostly sitting")),
    ("standing_or_walking", _("Mostly standing or walking")),
    ("physical_effort", _("Definite physical effort")),
    ("vigorous_physical_activity", _("Vigorous physical activity")),
)

PHYSICAL_ACTIVITY_HOURS = (
    ("none", _("None")),
    ("lt_1hr", _("Some but less than one hour")),
    ("1-3hr", _("1 hour but less than 3 hours")),
    (GTE_3HRS, _("3 hours or more")),
)


TRANSPORT_CHOICES = (
    ("bus", _("Bus")),
    ("train", _("Train")),
    ("ambulance", _("Ambulance")),
    ("private_taxi", _("Private taxi")),
    ("own_bicycle", _("Own bicycle")),
    ("hired_motorbike", _("Hired motorbike")),
    ("own_car", _("Own car")),
    ("own_motorbike", _("Own motorbike")),
    ("hired_bicycle", _("Hired bicycle")),
    ("foot", _("Foot")),
    (OTHER, _("Other, specify")),
)

VISIT_UNSCHEDULED_REASON = (
    ("routine_non_study", _("Routine appointment (non-study)")),
    ("patient_unwell_outpatient", _("Patient unwell")),
    ("drug_refill", _("Drug refill only")),
    (OTHER, _("Other")),
    (NOT_APPLICABLE, _("Not applicable")),
)

VISIT_REASON = (
    (SCHEDULED, _("Scheduled visit (study)")),
    (UNSCHEDULED, _("Routine / Unscheduled visit (non-study)")),
    (MISSED_VISIT, _("Missed visit")),
)

ESTIMATED_MEASURED_CHOICES = (
    (MEASURED, _("Measured")),
    (ESTIMATED, _("Estimated")),
    (NOT_APPLICABLE, _("Not recorded / Not applicable")),
)

APPT_DATE_INFO_SOURCES = (
    ("health_records", _("Health record")),
    (PATIENT, _("Patient")),
    ("estimated", _("I estimated the date")),
)


TRAVEL_METHODS = Choices(
    ("walking", _("Walking"), 1),
    ("public_transport", _("Public Transport (government bus, etc)")),
    ("hired_transport", _("Hired / shared transport (bus, taxi, boda boda etc)")),
    (
        "own_transport",
        _(
            "Own vehicle (bicycle, animal-drawn cart, motorcycle, scooter, tractor, car, etc)",
        ),
    ),
    (
        "borrowed_transport",
        (
            _(
                "Somebody else’s vehicle (bicycle, animal-drawn cart, "
                "motorcycle, scooter, tractor, car, etc)"
            )
        ),
    ),
    fillmeta=True,
)

VISIT_REASONS = Choices(
    ("routine", "Regular follow-up/check-up", 1),
    ("tests", "Diagnostic tests"),
    ("refill", "Medicines pick-up/refill"),
    ("unwell", "Need treatment/care for illness"),
    (STUDY_VISIT, "Only for study visit"),
    (OTHER, "Other, please specify ..."),
    fillmeta=True,
)


MEDS = Choices(
    (HIV, "HIV", 1),
    (HTN, "Hypertension"),
    (DM, "Diabetes"),
    (OTHER, "Other, please specify ..."),
    fillmeta=True,
)

MED_COLLECTION_LOCATIONS = Choices(
    ("public_pharmacy", "Public pharmacy"),
    ("private_pharmacy", "Private pharmacy"),
    ("club", "Club"),
    (OTHER, "Other, please specify ..."),
    (NOT_APPLICABLE, "Not applicable"),
    fillmeta=True,
)

NOT_COLLECTED_REASONS = Choices(
    ("meds_at_home", "Already had the medicines at home", 1),
    (UNAVAILABLE, "Medicines were not available"),
    (EXPENSIVE, "Medicines were too expensive"),
    (HOME_REMEDIES, "Home remedies are better"),
    (UNIMPORTANT, "Did not think it was important to get these medicines"),
    (TOO_BUSY, "Did not have the time to collect or buy medicines"),
    (PROBLEMATIC, "Taking medicines caused problems"),
    (OTHER, "Other, please specify ..."),
    (NOT_APPLICABLE, "Not applicable"),
    fillmeta=True,
)


TESTS_NOT_DONE_REASONS = Choices(
    (UNAVAILABLE, "Tests were not available and not done", 1),
    (EXPENSIVE, "Tests were too expensive"),
    (UNIMPORTANT, "Did not think it was important to do these tests "),
    (TOO_BUSY, "Did not have the time to do these tests"),
    (OTHER, "Other, please specify ..."),
    (NOT_APPLICABLE, "Not applicable"),
    fillmeta=True,
)

FACILITY_VISIT_ALTERNATIVES = Choices(
    (
        PAID_WORK,
        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
        1,
    ),
    (UNPAID_WORK, "Unpaid work (e.g. subsistence farming, housework etc.)"),
    (OTHER, "Other (specify)"),
    fillmeta=True,
)

FACILITY_VISIT_ALTERNATIVES_NA = Choices(
    (
        PAID_WORK,
        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
        1,
    ),
    (UNPAID_WORK, "Unpaid work (e.g. subsistence farming, housework etc.)"),
    (OTHER, "Other (specify)"),
    (NOT_APPLICABLE, "Not applicable"),
    fillmeta=True,
)

REFERRAL_TYPE = Choices(
    ("inpatient", "Inpatient", 1),
    ("outpatient", "Outpatient (includes laboratory testing)"),
    (NOT_APPLICABLE, "Not applicable"),
    fillmeta=True,
)

REFERRAL_FACILITY = Choices(
    ("public_clinic", "Public facility below tertiary level", 1),
    ("private_clinic", "Private clinic"),
    ("private_dx_facility", "Private diagnostic facility"),
    ("ngo_clinic", "NGO clinic"),
    ("public_hospital", "Public Hospital/tertiary facility"),
    ("private_hospital", "Private hospital"),
    ("pharmacy", "Pharmacy"),
    (NOT_APPLICABLE, "Not applicable"),
    fillmeta=True,
)

_accompany = (
    (ALONE, "No one, I came alone", 1),
    (MAIN_EARNER, "Main household earner"),
    (ADULT, "Other family member/relatives/friends (adults)"),
    (CHILD, "Other family member/relatives/friends (children)"),
    (NOT_APPLICABLE, "Not applicable"),
)
ACCOMPANIED_BY = Choices(*[t for t in _accompany if t[0] != NOT_APPLICABLE], fillmeta=True)

ACCOMPANIED_BY_NA = Choices(*_accompany, fillmeta=True)

_MONEY_SOURCES = (
    ("own_savings", "Own saving (e.g. “loose funds”, bank savings)", 1),
    ("family_gift", "Money received from family members that does not need to be repaid"),
    ("family_loan", "Loan from family member that needs to be repaid"),
    (
        "gift_relative",
        "Money received from relative/neighbour that does not need to be repaid",
    ),
    ("loan_relative", "Loan from relative/neighbour that needs to be repaid"),
    ("loan_money_lender", "Loan from money lender"),
    ("loan_bank", "Loan from another source eg bank"),
    ("community", "Self-help community group"),
    ("national_insurance", "National health insurance"),
    ("private_insurance", "Private health insurance"),
    ("community_insurance", "Community health insurance"),
    ("waiver", "Government waiver"),
    (
        "asset_sale",
        "Sale of assets (property, livestock, jewellery, household goods, etc)",
    ),
    (OTHER, "Other (specified above)"),
    (NOT_APPLICABLE, "Not applicable"),
)
MONEY_SOURCES_NA = Choices(
    *_MONEY_SOURCES,
    fillmeta=True,
)
MONEY_SOURCES = Choices(
    *[t for t in _MONEY_SOURCES if t[0] != NOT_APPLICABLE],
    fillmeta=True,
)


NO_SEEK_REASONS = Choices(
    ("not_necessary", "Did not think it was necessary ", 1),
    ("recovered", "Recovered before I could go "),
    ("home_remedy", "Home remedy given by family member, relatives, neighbours "),
    ("too_expensive", "Too expensive "),
    ("no_time", "Wanted to but could not find time"),
    ("no_transport", "There was no one to take me"),
    ("facility_too_far", "The health facility is too far/ not easy to reach "),
    ("hcw_unavailable", "Health care practitioner mostly unavailable "),
    ("med_problems", "Taking medicines caused problems"),
    ("hcw_confusing", "Do not understand what the healthcare practitioner says "),
    ("hcw_incompetent", "Practitioner is not competent in their work "),
    (OTHER, "Other (specify)"),
    (NOT_APPLICABLE, "Not applicable"),
    fillmeta=True,
)

SEEK_FACILITIES = Choices(
    ("comm_health_centre", "Community health centre/health post", 1),
    ("gov_dispensary", "Government dispensary"),
    ("phc", "Primary health care center (PHC)"),
    ("private_clinic", "Private clinic"),
    ("ngo", "NGO clinic"),
    ("public_hospital", "Public Hospital"),
    ("private_hospital", "Private hospital"),
    ("pharmacy", "Pharmacy"),
    ("hcw_home", "Any healthcare practitioner’s home"),
    (OTHER, "Other (specify)"),
    (NOT_APPLICABLE, "Not applicable"),
    fillmeta=True,
)

SEEKK_CARE_TYPES = Choices(
    (OUTPATIENT, "Outpatient (includes laboratory testing)", 1),
    (INPATIENT, "Inpatient (stayed overnight for 1 or more nights)"),
    (BOTH, "Both"),
    (NOT_APPLICABLE, "Not applicable"),
    fillmeta=True,
)



# Generated by Django 5.0.4 on 2024-04-15 12:34

import django.core.validators
import edc_model_fields.fields.custom_django_fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0168_alter_careseekinga_money_source_main_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultsins",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="care_visit_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="Invalid format. Please insert a numeric values followed by “h” for hours, and a numeric values followed by “m” for minutes. For example, 1h2m, 0h35m, and so on",
                max_length=5,
                metadata="FFACTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How much time did you spend during your visit today -- from arrival to this place until the end of your visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="travel_time",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="Invalid format. Please insert a numeric values followed by “h” for hours, and a numeric values followed by “m” for minutes. For example, 1h2m, 0h35m, and so on",
                max_length=5,
                metadata="FTRATIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long did it take you to reach here?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="wait_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="Invalid format. Please insert a numeric values followed by “h” for hours, and a numeric values followed by “m” for minutes. For example, 1h2m, 0h35m, and so on",
                max_length=5,
                metadata="FWAITIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How much time did you spend waiting?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="with_hcw_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="Invalid format. Please insert a numeric values followed by “h” for hours, and a numeric values followed by “m” for minutes. For example, 1h2m, 0h35m, and so on",
                max_length=5,
                metadata="FWORKTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How much time did you spend with the healthcare worker?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="care_visit_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="in hours and minutes (format HH:MM)",
                max_length=5,
                metadata="FOUTTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="Roughly how much time did you spend during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="travel_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="in hours and minutes (format HH:MM)",
                max_length=5,
                metadata="FOUTTRATIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long did it take you to get there?",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="glucose_fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long did they fast (in hours and minutes)?",
            ),
        ),
        migrations.AlterField(
            model_name="dmreview",
            name="glucose_fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="glucose_fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="care_visit_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="Invalid format. Please insert a numeric values followed by “h” for hours, and a numeric values followed by “m” for minutes. For example, 1h2m, 0h35m, and so on",
                max_length=5,
                metadata="FFACTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How much time did you spend during your visit today -- from arrival to this place until the end of your visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="travel_time",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="Invalid format. Please insert a numeric values followed by “h” for hours, and a numeric values followed by “m” for minutes. For example, 1h2m, 0h35m, and so on",
                max_length=5,
                metadata="FTRATIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long did it take you to reach here?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="wait_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="Invalid format. Please insert a numeric values followed by “h” for hours, and a numeric values followed by “m” for minutes. For example, 1h2m, 0h35m, and so on",
                max_length=5,
                metadata="FWAITIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How much time did you spend waiting?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="with_hcw_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="Invalid format. Please insert a numeric values followed by “h” for hours, and a numeric values followed by “m” for minutes. For example, 1h2m, 0h35m, and so on",
                max_length=5,
                metadata="FWORKTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How much time did you spend with the healthcare worker?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="care_visit_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="in hours and minutes (format HH:MM)",
                max_length=5,
                metadata="FOUTTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="Roughly how much time did you spend during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="travel_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="in hours and minutes (format HH:MM)",
                max_length=5,
                metadata="FOUTTRATIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long did it take you to get there?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="glucose_fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long did they fast (in hours and minutes)?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreview",
            name="glucose_fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="glucose_fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc. No spaces allowed.",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
    ]



from django import forms
from edc_rx.modelform_mixins import DrugSupplyNcdModelFormMixin

from intecomm_lists.models import HtnTreatments

from ..models import DrugSupplyHtn


class DrugSupplyHtnForm(DrugSupplyNcdModelFormMixin, forms.ModelForm):
    list_model_cls = HtnTreatments
    relation_label = "drugsupplyhtn"

    class Meta:
        model = DrugSupplyHtn
        fields = "__all__"



# Generated by Django 4.1.2 on 2022-11-20 22:18

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0001_initial"),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name="healthtalklog",
            name="unique_lower_name_report_date",
        ),
        migrations.RemoveField(
            model_name="healthtalklog",
            name="health_facility_type",
        ),
        migrations.RemoveField(
            model_name="healthtalklog",
            name="health_facility_type_other",
        ),
        migrations.RemoveField(
            model_name="historicalhealthtalklog",
            name="health_facility_type",
        ),
        migrations.RemoveField(
            model_name="historicalhealthtalklog",
            name="health_facility_type_other",
        ),
        migrations.AddConstraint(
            model_name="healthtalklog",
            constraint=models.UniqueConstraint(
                models.F("health_facility"),
                models.F("report_date"),
                name="unique_health_facility_report_date",
                violation_error_message="Only one report expected per facility per day.",
            ),
        ),
    ]



# Generated by Django 4.1.2 on 2022-11-26 00:58
from django.db import migrations, models
from edc_constants.constants import DM, HIV, HTN


def update_patients_m2ms(apps, schema_editor):
    patient_group_cls = apps.get_model("intecomm_group.patientgroup")
    patient_group_cls.on_site = models.Manager()
    for obj in patient_group_cls._default_manager.all():
        obj.hiv_patients.clear()
        obj.dm_patients.clear()
        obj.htn_patients.clear()
        obj.multi_patients.clear()
        pks = []
        for patient_log in obj.patients.filter(conditions__name__in=[HIV]).exclude(
            conditions__name__in=[DM, HTN]
        ):
            pks.append(patient_log.pk)
            obj.hiv_patients.add(patient_log)
        for patient_log in obj.patients.filter(conditions__name__in=[DM]).exclude(
            conditions__name__in=[HIV, HTN]
        ):
            pks.append(patient_log.pk)
            obj.dm_patients.add(patient_log)
        for patient_log in obj.patients.filter(conditions__name__in=[HTN]).exclude(
            conditions__name__in=[HIV, DM]
        ):
            pks.append(patient_log.pk)
            obj.htn_patients.add(patient_log)
        for patient_log in obj.patients.exclude(pk__in=pks):
            obj.multi_patients.add(patient_log)


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_group", "0008_patientgroup_dm_patients_patientgroup_hiv_patients_and_more"),
    ]

    operations = [migrations.RunPython(update_patients_m2ms)]
